==> kibana-7.6.2p0.tgz: kibana/src/plugins/data/common/es_query/kuery/functions/index.js <==
"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.functions = void 0;

var is = _interopRequireWildcard(require("./is"));

var and = _interopRequireWildcard(require("./and"));

var or = _interopRequireWildcard(require("./or"));

var not = _interopRequireWildcard(require("./not"));

var range = _interopRequireWildcard(require("./range"));

var exists = _interopRequireWildcard(require("./exists"));

var geoBoundingBox = _interopRequireWildcard(require("./geo_bounding_box"));

var geoPolygon = _interopRequireWildcard(require("./geo_polygon"));

var nested = _interopRequireWildcard(require("./nested"));

function _interopRequireWildcard(obj) { if (obj && obj.__esModule) { return obj; } else { var newObj = {}; if (obj != null) { for (var key in obj) { if (Object.prototype.hasOwnProperty.call(obj, key)) { var desc = Object.defineProperty && Object.getOwnPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : {}; if (desc.get || desc.set) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } } newObj.default = obj; return newObj; } }

/*
 * Licensed to Elasticsearch B.V. under one or more contributor
 * license agreements. See the NOTICE file distributed with
 * this work for additional information regarding copyright
 * ownership. Elasticsearch B.V. licenses this file to you under
 * the Apache License, Version 2.0 (the "License"); you may
 * not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
const functions = {
  is,
  and,
  or,
  not,
  range,
  exists,
  geoBoundingBox,
  geoPolygon,
  nested
};
exports.functions = functions;

==> kibana-7.10.0.tgz: kibana/src/plugins/data/common/es_query/kuery/functions/index.js <==
"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.functions = void 0;

var is = _interopRequireWildcard(require("./is"));

var and = _interopRequireWildcard(require("./and"));

var or = _interopRequireWildcard(require("./or"));

var not = _interopRequireWildcard(require("./not"));

var range = _interopRequireWildcard(require("./range"));

var exists = _interopRequireWildcard(require("./exists"));

var geoBoundingBox = _interopRequireWildcard(require("./geo_bounding_box"));

var geoPolygon = _interopRequireWildcard(require("./geo_polygon"));

var nested = _interopRequireWildcard(require("./nested"));

function _getRequireWildcardCache() { if (typeof WeakMap !== "function") return null; var cache = new WeakMap(); _getRequireWildcardCache = function () { return cache; }; return cache; }

function _interopRequireWildcard(obj) { if (obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }

/*
 * Licensed to Elasticsearch B.V. under one or more contributor
 * license agreements. See the NOTICE file distributed with
 * this work for additional information regarding copyright
 * ownership. Elasticsearch B.V. licenses this file to you under
 * the Apache License, Version 2.0 (the "License"); you may
 * not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
const functions = {
  is,
  and,
  or,
  not,
  range,
  exists,
  geoBoundingBox,
  geoPolygon,
  nested
};
exports.functions = functions;
